pub struct BatchCloseAllResponse {
pub results: Option<Vec<BatchCloseResult>>,
pub total_closed: Option<i32>,
pub total_failed: Option<i32>,
pub total_requested: Option<i32>,
}Expand description
BatchCloseAllResponse
JSON schema
{
"type": "object",
"properties": {
"results": {
"type": [
"array",
"null"
],
"items": {
"$ref": "#/components/schemas/BatchCloseResult"
}
},
"totalClosed": {
"description": "Number of positions whose close order was accepted by the matching engine\n (SUCCESS, PARTIAL, or PENDING).",
"type": [
"integer",
"null"
],
"format": "int32"
},
"totalFailed": {
"description": "Number of positions whose close failed (validation, lookup, or a rejected\n close order).",
"type": [
"integer",
"null"
],
"format": "int32"
},
"totalRequested": {
"description": "Number of open positions the batch attempted to close.",
"type": [
"integer",
"null"
],
"format": "int32"
}
}
}Fields
results: Option<Vec<BatchCloseResult>>total_closed: Option<i32>Number of positions whose close order was accepted by the matching engine (SUCCESS, PARTIAL, or PENDING).
total_failed: Option<i32>Number of positions whose close failed (validation, lookup, or a rejected close order).
total_requested: Option<i32>Number of open positions the batch attempted to close.