pub struct Candle {
pub close: Option<String>,
pub close_timestamp_ms: Option<String>,
pub high: Option<String>,
pub low: Option<String>,
pub open: Option<String>,
pub quote_volume: Option<String>,
pub timestamp: Option<String>,
pub trade_count: Option<u32>,
pub volume: Option<String>,
}Expand description
Candle
JSON schema
{
"type": "object",
"properties": {
"close": {
"description": "Closing price",
"examples": [
"35200.00"
],
"type": [
"string",
"null"
]
},
"close_timestamp_ms": {
"description": "Unix timestamp for the end of the candle period in milliseconds",
"type": [
"string",
"null"
]
},
"high": {
"description": "Highest price during the period",
"examples": [
"35500.00"
],
"type": [
"string",
"null"
]
},
"low": {
"description": "Lowest price during the period",
"examples": [
"34800.00"
],
"type": [
"string",
"null"
]
},
"open": {
"description": "Opening price",
"examples": [
"35000.00"
],
"type": [
"string",
"null"
]
},
"quote_volume": {
"description": "Quote token volume traded during the period",
"examples": [
"4412600.00"
],
"type": [
"string",
"null"
]
},
"timestamp": {
"description": "Unix timestamp for the start of the candle period in milliseconds",
"type": [
"string",
"null"
]
},
"trade_count": {
"description": "Number of trades during the period",
"examples": [
342
],
"type": [
"integer",
"null"
],
"format": "uint32"
},
"volume": {
"description": "Base token volume traded during the period",
"examples": [
"125.5"
],
"type": [
"string",
"null"
]
}
}
}Fields
close: Option<String>Closing price
close_timestamp_ms: Option<String>Unix timestamp for the end of the candle period in milliseconds
high: Option<String>Highest price during the period
low: Option<String>Lowest price during the period
open: Option<String>Opening price
quote_volume: Option<String>Quote token volume traded during the period
timestamp: Option<String>Unix timestamp for the start of the candle period in milliseconds
trade_count: Option<u32>Number of trades during the period
volume: Option<String>Base token volume traded during the period