pub struct CreateDelegatedSessionResponse {
pub agent_address: Option<String>,
pub delegation_id: Option<Uuid>,
pub expires_at: Option<String>,
pub owner_user_id: Option<Uuid>,
}Expand description
CreateDelegatedSessionResponse
JSON schema
{
"type": "object",
"properties": {
"agentAddress": {
"description": "Agent wallet address recorded on the session for policy enforcement",
"type": [
"string",
"null"
]
},
"delegationId": {
"description": "Delegation UUID for the active (owner, agent) pair",
"type": [
"string",
"null"
],
"format": "uuid"
},
"expiresAt": {
"description": "Session expiry as a Unix timestamp (seconds)",
"examples": [
"1735689599"
],
"type": [
"string",
"null"
]
},
"ownerUserId": {
"description": "Owner account UUID the session acts on behalf of",
"type": [
"string",
"null"
],
"format": "uuid"
}
}
}Fields
agent_address: Option<String>Agent wallet address recorded on the session for policy enforcement
delegation_id: Option<Uuid>Delegation UUID for the active (owner, agent) pair
expires_at: Option<String>Session expiry as a Unix timestamp (seconds)
owner_user_id: Option<Uuid>Owner account UUID the session acts on behalf of