pub struct DelegatedAgentOwner {
pub delegation_id: Option<Uuid>,
pub expires_at: Option<String>,
pub is_active: Option<bool>,
pub name: Option<String>,
pub owner_user_id: Option<Uuid>,
}Expand description
DelegatedAgentOwner
JSON schema
{
"type": "object",
"properties": {
"delegationId": {
"description": "Delegation UUID for the (owner, agent) pair",
"type": [
"string",
"null"
],
"format": "uuid"
},
"expiresAt": {
"description": "Delegation expiry timestamp (ISO 8601), if set",
"type": [
"string",
"null"
]
},
"isActive": {
"description": "Whether the delegation is active",
"type": [
"boolean",
"null"
]
},
"name": {
"description": "Human-friendly label the owner gave this agent, if any",
"type": [
"string",
"null"
]
},
"ownerUserId": {
"description": "Owner account UUID to pass to CreateDelegatedSession",
"examples": [
"123e4567-e89b-12d3-a456-426614174000"
],
"type": [
"string",
"null"
],
"format": "uuid"
}
}
}Fields
delegation_id: Option<Uuid>Delegation UUID for the (owner, agent) pair
expires_at: Option<String>Delegation expiry timestamp (ISO 8601), if set
is_active: Option<bool>Whether the delegation is active
name: Option<String>Human-friendly label the owner gave this agent, if any
owner_user_id: Option<Uuid>Owner account UUID to pass to CreateDelegatedSession