pub struct GetAvailableCollateralResponse {
pub asset: Option<String>,
pub margin_available_collateral: Option<String>,
pub margin_transferable: Option<String>,
pub wallet_available: Option<String>,
pub wallet_locked: Option<String>,
}Expand description
GetAvailableCollateralResponse
JSON schema
{
"type": "object",
"properties": {
"asset": {
"type": [
"string",
"null"
]
},
"marginAvailableCollateral": {
"description": "Free collateral currently held in the user's parent margin account for this\n asset (equity minus initial margin required), i.e. collateral already inside\n margin and available to open new positions or transfer back out. Absent when\n the user has no margin account yet.",
"type": [
"string",
"null"
]
},
"marginTransferable": {
"type": [
"string",
"null"
]
},
"walletAvailable": {
"type": [
"string",
"null"
]
},
"walletLocked": {
"type": [
"string",
"null"
]
}
}
}Fields
asset: Option<String>margin_available_collateral: Option<String>Free collateral currently held in the user’s parent margin account for this asset (equity minus initial margin required), i.e. collateral already inside margin and available to open new positions or transfer back out. Absent when the user has no margin account yet.
margin_transferable: Option<String>wallet_available: Option<String>wallet_locked: Option<String>Trait Implementations
Sourceimpl Clone for GetAvailableCollateralResponse
impl Clone for GetAvailableCollateralResponse
Sourcefn clone(&self) -> GetAvailableCollateralResponse
fn clone(&self) -> GetAvailableCollateralResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for GetAvailableCollateralResponse
impl<'de> Deserialize<'de> for GetAvailableCollateralResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more