pub struct GetMarketStatsResponse {
pub total_quote_volume_ltd: Option<String>,
pub total_trade_count_ltd: Option<String>,
}Expand description
Exchange-wide life-to-date cumulative market statistics across all trading pairs.
JSON schema
{
"description": "Exchange-wide life-to-date cumulative market statistics across all trading pairs.",
"type": "object",
"properties": {
"totalQuoteVolumeLtd": {
"description": "Life-to-date cumulative quote-token (notional) volume summed across all trading pairs",
"examples": [
"48217365920.75"
],
"type": [
"string",
"null"
]
},
"totalTradeCountLtd": {
"description": "Life-to-date cumulative number of trades summed across all trading pairs",
"examples": [
"19284736"
],
"type": [
"string",
"null"
]
}
}
}Fields
total_quote_volume_ltd: Option<String>Life-to-date cumulative quote-token (notional) volume summed across all trading pairs
total_trade_count_ltd: Option<String>Life-to-date cumulative number of trades summed across all trading pairs