pub struct GetProfileResponse {
pub account_type: Option<String>,
pub address: Option<GetProfileResponseAddress>,
pub application_maker_fee_bps: Option<i32>,
pub application_taker_fee_bps: Option<i32>,
pub can_withdraw: Option<bool>,
pub created_at: Option<String>,
pub id: Option<Uuid>,
pub maker_fee_bps: Option<i32>,
pub taker_fee_bps: Option<i32>,
pub username: Option<String>,
}Expand description
GetProfileResponse
JSON schema
{
"type": "object",
"properties": {
"account_type": {
"description": "Account type: master or sub",
"examples": [
"master"
],
"type": [
"string",
"null"
]
},
"address": {
"description": "Wallet address",
"type": [
"string",
"null"
],
"maxLength": 42,
"minLength": 42,
"pattern": "^0x[0-9a-fA-F]{40}$"
},
"application_maker_fee_bps": {
"description": "Additional maker fee in basis points from application",
"examples": [
0
],
"type": [
"integer",
"null"
],
"format": "int32"
},
"application_taker_fee_bps": {
"description": "Additional taker fee in basis points from application",
"examples": [
0
],
"type": [
"integer",
"null"
],
"format": "int32"
},
"can_withdraw": {
"description": "Whether the user is allowed to withdraw",
"examples": [
true
],
"type": [
"boolean",
"null"
]
},
"created_at": {
"description": "Account creation timestamp (ISO 8601)",
"examples": [
"2023-11-13T10:30:00Z"
],
"type": [
"string",
"null"
]
},
"id": {
"description": "User UUID",
"examples": [
"123e4567-e89b-12d3-a456-426614174000"
],
"type": [
"string",
"null"
],
"format": "uuid"
},
"maker_fee_bps": {
"description": "Base maker fee in basis points from active trading pair",
"examples": [
-1
],
"type": [
"integer",
"null"
],
"format": "int32"
},
"taker_fee_bps": {
"description": "Base taker fee in basis points from active trading pair",
"examples": [
5
],
"type": [
"integer",
"null"
],
"format": "int32"
},
"username": {
"description": "Display username",
"examples": [
"trader123"
],
"type": [
"string",
"null"
]
}
}
}Fields
account_type: Option<String>Account type: master or sub
address: Option<GetProfileResponseAddress>Wallet address
application_maker_fee_bps: Option<i32>Additional maker fee in basis points from application
application_taker_fee_bps: Option<i32>Additional taker fee in basis points from application
can_withdraw: Option<bool>Whether the user is allowed to withdraw
created_at: Option<String>Account creation timestamp (ISO 8601)
id: Option<Uuid>User UUID
maker_fee_bps: Option<i32>Base maker fee in basis points from active trading pair
taker_fee_bps: Option<i32>Base taker fee in basis points from active trading pair
username: Option<String>Display username