pub struct PositionHistoryEvent {Show 18 fields
pub action: Option<String>,
pub allocated_initial_margin: Option<String>,
pub collateral_change: Option<String>,
pub created_at: Option<String>,
pub entry_price: Option<String>,
pub fees_paid: Option<String>,
pub funding_paid: Option<String>,
pub id: Option<String>,
pub margin_account_id: Option<String>,
pub net_realized_pnl: Option<String>,
pub order_id: Option<Uuid>,
pub position_id: Option<String>,
pub position_side: Option<String>,
pub price: Option<String>,
pub realized_pnl: Option<String>,
pub realized_roe: Option<String>,
pub size_change: Option<String>,
pub trading_pair_id: Option<Uuid>,
}Expand description
PositionHistoryEvent
JSON schema
{
"type": "object",
"properties": {
"action": {
"type": [
"string",
"null"
]
},
"allocatedInitialMargin": {
"description": "Initial margin allocated pro rata to this reduction execution.",
"type": [
"string",
"null"
]
},
"collateralChange": {
"type": [
"string",
"null"
]
},
"createdAt": {
"type": [
"string",
"null"
]
},
"entryPrice": {
"description": "Average entry price immediately before this reduction execution.",
"type": [
"string",
"null"
]
},
"feesPaid": {
"type": [
"string",
"null"
]
},
"fundingPaid": {
"description": "Funding allocated pro rata to this reduction; positive means paid.",
"type": [
"string",
"null"
]
},
"id": {
"type": [
"string",
"null"
]
},
"marginAccountId": {
"type": [
"string",
"null"
]
},
"netRealizedPnl": {
"description": "Realized PnL after trading fees and funding for this reduction execution.",
"type": [
"string",
"null"
]
},
"orderId": {
"type": [
"string",
"null"
],
"format": "uuid"
},
"positionId": {
"type": [
"string",
"null"
]
},
"positionSide": {
"description": "Position side immediately before this reduction execution.",
"type": [
"string",
"null"
]
},
"price": {
"type": [
"string",
"null"
]
},
"realizedPnl": {
"type": [
"string",
"null"
]
},
"realizedRoe": {
"description": "Net realized PnL divided by allocated_initial_margin, expressed as a percentage.",
"type": [
"string",
"null"
]
},
"sizeChange": {
"type": [
"string",
"null"
]
},
"tradingPairId": {
"type": [
"string",
"null"
],
"format": "uuid"
}
}
}Fields
action: Option<String>allocated_initial_margin: Option<String>Initial margin allocated pro rata to this reduction execution.
collateral_change: Option<String>created_at: Option<String>entry_price: Option<String>Average entry price immediately before this reduction execution.
fees_paid: Option<String>funding_paid: Option<String>Funding allocated pro rata to this reduction; positive means paid.
id: Option<String>margin_account_id: Option<String>net_realized_pnl: Option<String>Realized PnL after trading fees and funding for this reduction execution.
order_id: Option<Uuid>position_id: Option<String>position_side: Option<String>Position side immediately before this reduction execution.
price: Option<String>realized_pnl: Option<String>realized_roe: Option<String>Net realized PnL divided by allocated_initial_margin, expressed as a percentage.
size_change: Option<String>trading_pair_id: Option<Uuid>Trait Implementations
Sourceimpl Clone for PositionHistoryEvent
impl Clone for PositionHistoryEvent
Sourcefn clone(&self) -> PositionHistoryEvent
fn clone(&self) -> PositionHistoryEvent
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PositionHistoryEvent
impl Debug for PositionHistoryEvent
Sourceimpl Default for PositionHistoryEvent
impl Default for PositionHistoryEvent
Sourceimpl<'de> Deserialize<'de> for PositionHistoryEvent
impl<'de> Deserialize<'de> for PositionHistoryEvent
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more