pub struct TransferCollateralFromMarginAccountRequest {
pub amount: Option<String>,
pub asset: Option<String>,
pub margin_account_id: Option<String>,
pub strategy_key: Option<String>,
pub trading_pair_id: Option<Uuid>,
}Expand description
TransferCollateralFromMarginAccountRequest
JSON schema
{
"type": "object",
"properties": {
"amount": {
"type": [
"string",
"null"
]
},
"asset": {
"type": [
"string",
"null"
]
},
"marginAccountId": {
"description": "Parent margin account UUID that releases collateral.",
"type": [
"string",
"null"
]
},
"strategyKey": {
"description": "Optional strategy key echoed in responses when callers scope a risk bucket.",
"type": [
"string",
"null"
]
},
"tradingPairId": {
"description": "Optional trading pair UUID used to release collateral from an isolated risk\n bucket under the parent margin account. If omitted, the transfer applies to\n the parent margin account only.",
"type": [
"string",
"null"
],
"format": "uuid"
}
}
}Fields
amount: Option<String>asset: Option<String>margin_account_id: Option<String>Parent margin account UUID that releases collateral.
strategy_key: Option<String>Optional strategy key echoed in responses when callers scope a risk bucket.
trading_pair_id: Option<Uuid>Optional trading pair UUID used to release collateral from an isolated risk bucket under the parent margin account. If omitted, the transfer applies to the parent margin account only.