pub struct TransferCollateralToMarginAccountResponse {
pub amount: Option<String>,
pub asset: Option<String>,
pub margin_account_id: Option<String>,
pub margin_mode: Option<String>,
pub movement_id: Option<String>,
pub new_equity: Option<String>,
pub new_total_collateral_value: Option<String>,
pub new_withdrawable_collateral: Option<String>,
pub risk_bucket_id: Option<String>,
pub selected_trading_pair_ids: Option<Vec<Uuid>>,
pub status: Option<String>,
pub strategy_key: Option<String>,
}Expand description
TransferCollateralToMarginAccountResponse
JSON schema
{
"type": "object",
"properties": {
"amount": {
"type": [
"string",
"null"
]
},
"asset": {
"type": [
"string",
"null"
]
},
"marginAccountId": {
"type": [
"string",
"null"
]
},
"marginMode": {
"description": "Present when collateral was allocated to a risk bucket. Values: ISOLATED, CROSS.",
"type": [
"string",
"null"
]
},
"movementId": {
"type": [
"string",
"null"
]
},
"newEquity": {
"type": [
"string",
"null"
]
},
"newTotalCollateralValue": {
"type": [
"string",
"null"
]
},
"newWithdrawableCollateral": {
"type": [
"string",
"null"
]
},
"riskBucketId": {
"description": "Present when collateral was allocated to a risk bucket.",
"type": [
"string",
"null"
]
},
"selectedTradingPairIds": {
"description": "Present for cross risk-bucket transfers.",
"type": [
"array",
"null"
],
"items": {
"type": "string",
"format": "uuid",
"minLength": 1
}
},
"status": {
"type": [
"string",
"null"
]
},
"strategyKey": {
"type": [
"string",
"null"
]
}
}
}Fields
amount: Option<String>asset: Option<String>margin_account_id: Option<String>margin_mode: Option<String>Present when collateral was allocated to a risk bucket. Values: ISOLATED, CROSS.
movement_id: Option<String>new_equity: Option<String>new_total_collateral_value: Option<String>new_withdrawable_collateral: Option<String>risk_bucket_id: Option<String>Present when collateral was allocated to a risk bucket.
selected_trading_pair_ids: Option<Vec<Uuid>>Present for cross risk-bucket transfers.
status: Option<String>strategy_key: Option<String>Trait Implementations
Sourceimpl Clone for TransferCollateralToMarginAccountResponse
impl Clone for TransferCollateralToMarginAccountResponse
Sourcefn clone(&self) -> TransferCollateralToMarginAccountResponse
fn clone(&self) -> TransferCollateralToMarginAccountResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for TransferCollateralToMarginAccountResponse
impl<'de> Deserialize<'de> for TransferCollateralToMarginAccountResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more