pub struct CreateDelegatedSessionRequest {
pub owner_user_id: Option<Uuid>,
pub session_public_key: Option<String>,
}Expand description
CreateDelegatedSessionRequest
JSON schema
{
"type": "object",
"properties": {
"ownerUserId": {
"description": "Owner account UUID to act on behalf of (discover via ListDelegatedAgentOwners)",
"examples": [
"123e4567-e89b-12d3-a456-426614174000"
],
"type": [
"string",
"null"
],
"format": "uuid"
},
"sessionPublicKey": {
"description": "Lowercase-hex (64 chars) ed25519 public key the agent generated for this delegated session. Subsequent requests acting on the owner's behalf are signed with the matching private key.",
"type": [
"string",
"null"
]
}
}
}Fields
owner_user_id: Option<Uuid>Owner account UUID to act on behalf of (discover via ListDelegatedAgentOwners)
session_public_key: Option<String>Lowercase-hex (64 chars) ed25519 public key the agent generated for this delegated session. Subsequent requests acting on the owner’s behalf are signed with the matching private key.