pub struct GetPositionResponse {Show 19 fields
pub entry_price: Option<String>,
pub index_price: Option<String>,
pub initial_margin_required: Option<String>,
pub isolated_margin: Option<String>,
pub leverage: Option<String>,
pub liquidation_price: Option<String>,
pub maintenance_margin_required: Option<String>,
pub margin_account_id: Option<String>,
pub margin_mode: Option<String>,
pub mark_price: Option<String>,
pub position_id: Option<String>,
pub realized_pnl: Option<String>,
pub risk_bucket_id: Option<String>,
pub side: Option<String>,
pub size: Option<String>,
pub status: Option<String>,
pub trading_pair_id: Option<Uuid>,
pub unrealized_pnl: Option<String>,
pub updated_at: Option<String>,
}Expand description
GetPositionResponse
JSON schema
{
"type": "object",
"properties": {
"entryPrice": {
"type": [
"string",
"null"
]
},
"indexPrice": {
"type": [
"string",
"null"
]
},
"initialMarginRequired": {
"description": "Initial margin required by this position at mark_price, honoring both its\n effective leverage and the market initial-margin floor. Zero when the\n position has no open exposure.",
"type": [
"string",
"null"
]
},
"isolatedMargin": {
"description": "Current isolated collateral for this position's margin-account bucket.",
"type": [
"string",
"null"
]
},
"leverage": {
"type": [
"string",
"null"
]
},
"liquidationPrice": {
"type": [
"string",
"null"
]
},
"maintenanceMarginRequired": {
"description": "Maintenance margin required by this position at mark_price using the\n market maintenance-margin rate. Zero when the position has no open exposure.",
"type": [
"string",
"null"
]
},
"marginAccountId": {
"description": "Margin account UUID for the isolated bucket that owns this position.",
"type": [
"string",
"null"
]
},
"marginMode": {
"type": [
"string",
"null"
]
},
"markPrice": {
"type": [
"string",
"null"
]
},
"positionId": {
"type": [
"string",
"null"
]
},
"realizedPnl": {
"type": [
"string",
"null"
]
},
"riskBucketId": {
"type": [
"string",
"null"
]
},
"side": {
"type": [
"string",
"null"
]
},
"size": {
"type": [
"string",
"null"
]
},
"status": {
"type": [
"string",
"null"
]
},
"tradingPairId": {
"type": [
"string",
"null"
],
"format": "uuid"
},
"unrealizedPnl": {
"type": [
"string",
"null"
]
},
"updatedAt": {
"type": [
"string",
"null"
]
}
}
}Fields
entry_price: Option<String>index_price: Option<String>initial_margin_required: Option<String>Initial margin required by this position at mark_price, honoring both its effective leverage and the market initial-margin floor. Zero when the position has no open exposure.
isolated_margin: Option<String>Current isolated collateral for this position’s margin-account bucket.
leverage: Option<String>liquidation_price: Option<String>maintenance_margin_required: Option<String>Maintenance margin required by this position at mark_price using the market maintenance-margin rate. Zero when the position has no open exposure.
margin_account_id: Option<String>Margin account UUID for the isolated bucket that owns this position.
margin_mode: Option<String>mark_price: Option<String>position_id: Option<String>realized_pnl: Option<String>risk_bucket_id: Option<String>side: Option<String>size: Option<String>status: Option<String>trading_pair_id: Option<Uuid>unrealized_pnl: Option<String>updated_at: Option<String>Trait Implementations
Sourceimpl Clone for GetPositionResponse
impl Clone for GetPositionResponse
Sourcefn clone(&self) -> GetPositionResponse
fn clone(&self) -> GetPositionResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for GetPositionResponse
impl Debug for GetPositionResponse
Sourceimpl Default for GetPositionResponse
impl Default for GetPositionResponse
Sourceimpl<'de> Deserialize<'de> for GetPositionResponse
impl<'de> Deserialize<'de> for GetPositionResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more